import { OnsiteCoreWindow } from "@mailbiz/onsite-core";
//#region [Window]
interface VndaWindow extends OnsiteCoreWindow {
    Vnda: VndaContext;
    next: VndaCheckoutFrameworkContext;
}
//#endregion
//#region [Vnda variant properties]
interface VndaVariantProperties {
    property1: VndaVariantProperty;
    property2: VndaVariantProperty;
    property3: VndaVariantProperty;
}
interface VndaVariantProperty {
    name: string;
    value: string;
    defining: boolean;
}
//#endregion
//#region [Vnda context]
interface VndaContext {
    variants: VndaVariants;
}
interface VndaVariants {
    variant_list: VndaVariant[];
}
interface VndaVariant {
    id: number;
    sku: string;
    sku_lowercase: string;
    name: string;
    full_name: string;
    main: boolean;
    available: boolean;
    image_url: any;
    price: number;
    sale_price: number;
    intl_price: number;
    installments: Array<{
        number: number;
        price: number;
        interest: boolean;
        interest_rate: number;
        total: number;
    }>;
    stock: number;
    quantity: number;
    quantity_sold: number;
    min_quantity: number;
    available_quantity: number;
    custom_attributes: any;
    attribute1: string;
    attribute2: any;
    attribute3: any;
    properties: VndaVariantProperties;
    inventories: Array<any>;
    handling_days: number;
    barcode: string;
    weight: number;
    width: number;
    height: number;
    length: number;
    restocking_enabled: boolean;
    restocking_days: number;
}
//#endregion
//#region [Carrinho context]
interface VndaCart {
    agent: any;
    billing_address_id: any;
    cashback_amount: number;
    channel: string;
    client_id: any;
    code: string;
    coupon_code: any;
    discount: any;
    discount_price: number;
    extra: any;
    id: number;
    installments: Array<number>;
    items: VndaCartItem[];
    items_count: number;
    shipping_address_id: any;
    shipping_method: any;
    shipping_methods: Array<any>;
    shipping_price: number;
    subtotal: number;
    subtotal_discount: number;
    token: string;
    total: number;
    total_discount: number;
    total_for_deposit: number;
    total_for_slip: number;
    total_for_pix: number;
    total_for_addi: number;
    updated_at: string;
    rebate_token: any;
    rebate_discount: number;
    user_id: any;
    handling_days: number;
    credits_discount: number;
}
interface VndaCartItem {
    id: number;
    quantity: number;
    price: number;
    subtotal: number;
    total: number;
    cashback_amount: number;
    extra: {};
    product_url: string;
    image_url: string;
    product_id: number;
    product_reference: string;
    product_name: string;
    product_type: string;
    variant_sku: string;
    variant_name: string;
    variant_min_quantity: number;
    variant_attributes: any;
    variant_properties: VndaVariantProperties;
    updated_at: string;
    available_quantity: number;
    variant_price: number;
    variant_intl_price: number;
    variant_barcode: string;
    variant_height: number;
    variant_length: number;
    variant_width: number;
    variant_weight: number;
    variant_handling_days: number;
    variant_restocking_days: number;
    variant_restocking_enabled: boolean;
    seller: any;
    seller_name: any;
    delivery_days: number;
    place_id: any;
    has_customizations: boolean;
    available: boolean;
    tags: Array<any>;
    pinterest_category_tag?: any;
    category_tags?: any;
}
//#endregion
//#region [Vnda client]
interface VndaClient {
    birthdate?: string;
    email: string;
    id?: number | null;
    recentAddress: {
        id: number | null;
        firstName: string | null;
        lastName: string | null;
        companyName: any;
        email: string | null;
        documents: {
            cpf?: string | null;
        };
        streetName: string | null;
        streetNumber: string | null;
        complement: string | null;
        neighborhood: string | null;
        firstPhoneArea: string | null;
        firstPhone: string | null;
        secondPhoneArea: any;
        secondPhone: any;
        reference: any;
        clientAddressId: any;
        zip: string | null;
        city: string | null;
        state: string | null;
    };
    savedAddresses?: Array<any>;
    optinCheckout?: boolean;
    isLogged?: boolean;
    hasOrders?: boolean;
}
//#endregion
//#region [Checkout framework]
interface VndaCheckoutFrameworkContext {
    router: {
        components: {
            "/[[...props]]"?: {
                props: {
                    pageProps: {
                        cart?: VndaCart;
                        client?: VndaClient;
                    };
                };
            };
            "/concluido/[token]"?: {
                props: {
                    pageProps: {
                        order: OrderCompleteVndaCart;
                    };
                };
            };
        };
    };
}
//#endregion
//#region [Order complete Vnda cart]
interface OrderCompleteVndaCart {
    code: string;
    token: string;
    client_id: number;
    coupon_code: any;
    delivery_days: number;
    delivery_message: string;
    deposit: boolean;
    discount_price: number;
    credits_discount: number;
    email: string;
    extra: any;
    items: OrderCompleteVndaCartItem[];
    installments: number;
    payment_method: string;
    shipping_label: string;
    shipping_price: number;
    delivery_type: string;
    status: string;
    subtotal: number;
    total: number;
    slip: boolean;
    slip_url: string | null;
    card: boolean;
    pix: boolean;
    pix_qr_code: any;
    ame: boolean;
    ame_qr_code: any;
    qr_code_data: any;
    payment_due_date: string;
    slip_due_date: string;
    expected_delivery_date: string;
    taxes: number;
    channel: string;
    user_id: any;
}
interface OrderCompleteVndaCartItem {
    id: number;
    variant_id: number;
    product_id: number;
    quantity: number;
    restocking_quantity: number;
    price: number;
    weight: number;
    width: number;
    height: number;
    length: number;
    extra: {};
    picture_url: string;
    reference: string;
    sku: string;
    product_name: string;
    variant_name: string;
    original_price: number;
    place_id: any;
    place_name: any;
    place_city: any;
    total: number;
    package: string;
    has_customizations: boolean;
    barcode: string | null;
    pinterest_category_tag?: any;
}
declare global {
    interface Window extends VndaWindow {
    }
}
